Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
aiopromql/__init__.py | (no function) | 3 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusClientBase.__init__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusClientBase._parse_response | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync.__init__ | 2 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync.query | 3 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync.query_range | 5 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync.close | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync.__del__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.__init__ | 2 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.query | 3 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.query_range | 5 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.aclose | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.__aenter__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.__aexit__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync.__del__ | 2 | 1 | 0 | 2 | 1 | 50%
aiopromql/client.py | (no function) | 22 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/__init__.py | (no function) | 0 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | MetricLabelSet.__init__ | 2 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | MetricLabelSet.__hash__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | MetricLabelSet.__eq__ | 3 | 0 | 0 | 2 | 0 | 100%
aiopromql/models/core.py | MetricLabelSet.__repr__ | 1 | 1 | 0 | 0 | 0 | 0%
aiopromql/models/core.py | MetricLabelSet.get | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeriesPoint.from_prometheus_value | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeriesPoint.__str__ | 1 | 1 | 0 | 0 | 0 | 0%
aiopromql/models/core.py | TimeSeries.__init__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.__iter__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.__len__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.__getitem__ | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.__repr__ | 1 | 1 | 0 | 0 | 0 | 0%
aiopromql/models/core.py | TimeSeries.add_point | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.extend | 1 | 1 | 0 | 0 | 0 | 0%
aiopromql/models/core.py | TimeSeries.latest | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | TimeSeries.average | 2 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | (no function) | 24 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | VectorDataModel.to_metric_map | 6 | 0 | 0 | 2 | 0 | 100%
aiopromql/models/prometheus.py | MatrixDataModel.to_metric_map | 7 | 0 | 0 | 4 | 0 | 100%
aiopromql/models/prometheus.py | PrometheusResponseModel.to_metric_map | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | (no function) | 22 | 0 | 0 | 0 | 0 | 100%
aiopromql/utils.py | make_label_string | 9 | 0 | 0 | 4 | 0 | 100%
aiopromql/utils.py | (no function) | 1 | 0 | 0 | 0 | 0 | 100%
Total |  | 144 | 5 | 0 | 14 | 1 | 96%

No items found using the specified filter.